summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAdam <Adam@anope.org>2010-11-14 15:12:32 -0500
committerAdam <Adam@anope.org>2010-12-12 19:33:58 -0500
commit3c9d4e9dafdd0918a3539e545cc99646e604757d (patch)
tree5206bf59ad26698932ca0119b2c04a5f70c88946 /include
parentc792c7f62df41c48d0d813a809e5415cbefa38b2 (diff)
Added command aliases
Diffstat (limited to 'include')
-rw-r--r--include/commands.h4
-rw-r--r--include/modules.h4
2 files changed, 4 insertions, 4 deletions
diff --git a/include/commands.h b/include/commands.h
index 545c9dd7b..5c0b5315c 100644
--- a/include/commands.h
+++ b/include/commands.h
@@ -30,8 +30,8 @@ enum CommandReturn
extern CoreExport Command *FindCommand(BotInfo *bi, const Anope::string &cmd);
extern CoreExport void mod_help_cmd(BotInfo *bi, User *u, const Anope::string &cmd);
-extern CoreExport void mod_run_cmd(BotInfo *bi, User *u, const Anope::string &message);
-extern CoreExport void mod_run_cmd(BotInfo *bi, User *u, Command *c, const Anope::string &command, const Anope::string &message);
+extern CoreExport void mod_run_cmd(BotInfo *bi, User *u, const Anope::string &message, bool fantasy);
+extern CoreExport void mod_run_cmd(BotInfo *bi, User *u, Command *c, const Anope::string &command, const Anope::string &message, bool fantasy);
enum CommandFlag
{
diff --git a/include/modules.h b/include/modules.h
index 7e7e69194..481b5180b 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -365,10 +365,10 @@ class CoreExport Module : public Extensible
* @param bi The bot the command is being run from
* @param command The command
* @param message The parameters used for the command
* @param c The command class (if it exists)
* @return EVENT_CONTINUE to let other modules decide, EVENT_STOP to halt the command and not process it
*/
- virtual EventReturn OnPreCommandRun(User *u, BotInfo *bi, const Anope::string &command, const Anope::string &message, Command *c) { return EVENT_CONTINUE; }
+ virtual EventReturn OnPreCommandRun(User *u, BotInfo *bi, Anope::string &command, Anope::string &message, bool fantasy) { return EVENT_CONTINUE; }
/** Called before a command is due to be executed.
* @param u The user executing the command
@@ -365,10 +365,10 @@ class CoreExport Module : public Extensible
* @param command The command
* @param message The parameters used for the command
- * @param c The command class (if it exists)
+ * @param fantasy true if this is a fantasy command
* @return EVENT_CONTINUE to let other modules decide, EVENT_STOP to halt the command and not process it
*/